BEGIN TRANSACTION

--
SET QUOTED_IDENTIFIER ON
SET ARITHABORT ON
SET NUMERIC_ROUNDABORT OFF
SET CONCAT_NULL_YIELDS_NULL ON
SET ANSI_NULLS ON
SET ANSI_PADDING ON
SET ANSI_WARNINGS ON
--
--
CREATE TABLE dbo.Tmp_CuteChat4_InstantMessage
	(
	MessageId int NOT NULL IDENTITY (1, 1),
	MsgTime datetime NOT NULL,
	Sender nvarchar(100) NOT NULL,
	SenderId nvarchar(100) NOT NULL,
	Target nvarchar(100) NOT NULL,
	TargetId nvarchar(100) NOT NULL,
	Offline int NOT NULL,
	DeletedBySender int NULL,
	DeletedByTarget int NULL,
	IPAddress nvarchar(25) NOT NULL,
	Text ntext NULL,
	Html ntext NULL
	)  ON [PRIMARY]
	 TEXTIMAGE_ON [PRIMARY]
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_InstantMessage ON
GO
IF EXISTS(SELECT * FROM dbo.CuteChat4_InstantMessage)
	 EXEC('INSERT INTO dbo.Tmp_CuteChat4_InstantMessage (MessageId, MsgTime, Sender, SenderId, Target, TargetId, Offline, DeletedBySender, DeletedByTarget, IPAddress, Text, Html)
		SELECT MessageId, MsgTime, Sender, SenderId, Target, TargetId, Offline, DeletedBySender, DeletedByTarget, IPAddress, Text, Html FROM dbo.CuteChat4_InstantMessage (HOLDLOCK TABLOCKX)')
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_InstantMessage OFF
GO
DROP TABLE dbo.CuteChat4_InstantMessage
GO
EXECUTE sp_rename N'dbo.Tmp_CuteChat4_InstantMessage', N'CuteChat4_InstantMessage', 'OBJECT'
GO
ALTER TABLE dbo.CuteChat4_InstantMessage ADD CONSTRAINT
	PK_CuteChat4_InstantMessage PRIMARY KEY CLUSTERED 
	(
	MessageId
	) ON [PRIMARY]

GO
CREATE NONCLUSTERED INDEX IX_CuteChat4_InstantMessage ON dbo.CuteChat4_InstantMessage
	(
	MsgTime,
	Sender,
	SenderId,
	Target,
	TargetId,
	Offline,
	IPAddress
	) ON [PRIMARY]
GO
--
--
ALTER TABLE dbo.CuteChat4_LogMessage
	DROP CONSTRAINT DF_CuteChat4_LogMessage_Location
GO
CREATE TABLE dbo.Tmp_CuteChat4_LogMessage
	(
	MessageId int NOT NULL IDENTITY (1, 1),
	MsgTime datetime NOT NULL,
	Location nvarchar(50) NOT NULL,
	Place nvarchar(50) NOT NULL,
	Sender nvarchar(100) NULL,
	SenderId nvarchar(100) NULL,
	Target nvarchar(100) NULL,
	TargetId nvarchar(100) NULL,
	Whisper int NOT NULL,
	IPAddress nvarchar(25) NOT NULL,
	Text ntext NULL,
	Html ntext NULL
	)  ON [PRIMARY]
	 TEXTIMAGE_ON [PRIMARY]
GO
ALTER TABLE dbo.Tmp_CuteChat4_LogMessage ADD CONSTRAINT
	DF_CuteChat4_LogMessage_Location DEFAULT (N'Lobby') FOR Location
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_LogMessage ON
GO
IF EXISTS(SELECT * FROM dbo.CuteChat4_LogMessage)
	 EXEC('INSERT INTO dbo.Tmp_CuteChat4_LogMessage (MessageId, MsgTime, Location, Place, Sender, SenderId, Target, TargetId, Whisper, IPAddress, Text, Html)
		SELECT MessageId, MsgTime, Location, Place, Sender, SenderId, Target, TargetId, Whisper, IPAddress, Text, Html FROM dbo.CuteChat4_LogMessage (HOLDLOCK TABLOCKX)')
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_LogMessage OFF
GO
DROP TABLE dbo.CuteChat4_LogMessage
GO
EXECUTE sp_rename N'dbo.Tmp_CuteChat4_LogMessage', N'CuteChat4_LogMessage', 'OBJECT'
GO
ALTER TABLE dbo.CuteChat4_LogMessage ADD CONSTRAINT
	PK_CuteChat4_LogMessage PRIMARY KEY CLUSTERED 
	(
	MessageId
	) ON [PRIMARY]

GO
CREATE NONCLUSTERED INDEX IX_CuteChat4_LogMessage ON dbo.CuteChat4_LogMessage
	(
	MsgTime,
	Location,
	Place
	) ON [PRIMARY]
GO
--
--
CREATE TABLE dbo.Tmp_CuteChat4_SupportMessage
	(
	MessageId int NOT NULL IDENTITY (1, 1),
	MsgTime datetime NOT NULL,
	SessionId int NOT NULL,
	MsgType nvarchar(50) NOT NULL,
	Sender nvarchar(100) NULL,
	SenderId nvarchar(100) NULL,
	Target nvarchar(100) NULL,
	TargetId nvarchar(100) NULL,
	Text ntext NULL,
	Html ntext NULL
	)  ON [PRIMARY]
	 TEXTIMAGE_ON [PRIMARY]
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_SupportMessage ON
GO
IF EXISTS(SELECT * FROM dbo.CuteChat4_SupportMessage)
	 EXEC('INSERT INTO dbo.Tmp_CuteChat4_SupportMessage (MessageId, MsgTime, SessionId, MsgType, Sender, SenderId, Target, TargetId, Text, Html)
		SELECT MessageId, MsgTime, SessionId, MsgType, Sender, SenderId, Target, TargetId, CONVERT(ntext, Text), Html FROM dbo.CuteChat4_SupportMessage (HOLDLOCK TABLOCKX)')
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_SupportMessage OFF
GO
DROP TABLE dbo.CuteChat4_SupportMessage
GO
EXECUTE sp_rename N'dbo.Tmp_CuteChat4_SupportMessage', N'CuteChat4_SupportMessage', 'OBJECT'
GO
ALTER TABLE dbo.CuteChat4_SupportMessage ADD CONSTRAINT
	PK_CuteChat4_SupportMessage PRIMARY KEY CLUSTERED 
	(
	MessageId
	) ON [PRIMARY]

GO
--
--
ALTER TABLE dbo.CuteChat4_SupportSession
	DROP CONSTRAINT DF_CuteChat4_SupportSession_AgentRating
GO
CREATE TABLE dbo.Tmp_CuteChat4_SupportSession
	(
	SessionId int NOT NULL IDENTITY (1, 1),
	BeginTime datetime NOT NULL,
	DepartmentId int NOT NULL,
	AgentUserId nvarchar(100) NOT NULL,
	CustomerId nvarchar(100) NOT NULL,
	DisplayName nvarchar(100) NOT NULL,
	ActiveTime datetime NOT NULL,
	Email nvarchar(50) NULL,
	IPAddress nvarchar(50) NOT NULL,
	Culture nvarchar(50) NOT NULL,
	Platform nvarchar(50) NOT NULL,
	Browser nvarchar(50) NOT NULL,
	AgentRating int NOT NULL,
	SessionData ntext NULL
	)  ON [PRIMARY]
	 TEXTIMAGE_ON [PRIMARY]
GO
ALTER TABLE dbo.Tmp_CuteChat4_SupportSession ADD CONSTRAINT
	DF_CuteChat4_SupportSession_AgentRating DEFAULT (0) FOR AgentRating
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_SupportSession ON
GO
IF EXISTS(SELECT * FROM dbo.CuteChat4_SupportSession)
	 EXEC('INSERT INTO dbo.Tmp_CuteChat4_SupportSession (SessionId, BeginTime, DepartmentId, AgentUserId, CustomerId, DisplayName, ActiveTime, Email, IPAddress, Culture, Platform, Browser, AgentRating, SessionData)
		SELECT SessionId, BeginTime, DepartmentId, AgentUserId, CustomerId, DisplayName, ActiveTime, Email, IPAddress, Culture, Platform, Browser, AgentRating, SessionData FROM dbo.CuteChat4_SupportSession (HOLDLOCK TABLOCKX)')
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_SupportSession OFF
GO
DROP TABLE dbo.CuteChat4_SupportSession
GO
EXECUTE sp_rename N'dbo.Tmp_CuteChat4_SupportSession', N'CuteChat4_SupportSession', 'OBJECT'
GO
ALTER TABLE dbo.CuteChat4_SupportSession ADD CONSTRAINT
	PK_CuteChat4_SupportSession PRIMARY KEY CLUSTERED 
	(
	SessionId
	) ON [PRIMARY]

GO
CREATE NONCLUSTERED INDEX IX_CuteChat4_SupportSession_CustomerId ON dbo.CuteChat4_SupportSession
	(
	CustomerId
	) ON [PRIMARY]
GO
CREATE NONCLUSTERED INDEX IX_CuteChat4_SupportSession_Query ON dbo.CuteChat4_SupportSession
	(
	BeginTime,
	DepartmentId,
	AgentUserId,
	CustomerId
	) ON [PRIMARY]
GO
--
--
CREATE TABLE dbo.Tmp_CuteChat4_SupportFeedback
	(
	FeedbackId int NOT NULL IDENTITY (1, 1),
	FbTime datetime NOT NULL,
	CustomerId nvarchar(100) NULL,
	DisplayName nvarchar(100) NULL,
	Name nvarchar(100) NOT NULL,
	Email nvarchar(100) NOT NULL,
	Title nvarchar(200) NOT NULL,
	Content ntext NOT NULL,
	Comment ntext NULL,
	CommentBy nvarchar(100) NULL
	)  ON [PRIMARY]
	 TEXTIMAGE_ON [PRIMARY]
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_SupportFeedback ON
GO
IF EXISTS(SELECT * FROM dbo.CuteChat4_SupportFeedback)
	 EXEC('INSERT INTO dbo.Tmp_CuteChat4_SupportFeedback (FeedbackId, FbTime, CustomerId, DisplayName, Name, Email, Title, Content, Comment, CommentBy)
		SELECT FeedbackId, FbTime, CustomerId, DisplayName, Name, Email, Title, Content, Comment, CommentBy FROM dbo.CuteChat4_SupportFeedback (HOLDLOCK TABLOCKX)')
GO
SET IDENTITY_INSERT dbo.Tmp_CuteChat4_SupportFeedback OFF
GO
DROP TABLE dbo.CuteChat4_SupportFeedback
GO
EXECUTE sp_rename N'dbo.Tmp_CuteChat4_SupportFeedback', N'CuteChat4_SupportFeedback', 'OBJECT'
GO
ALTER TABLE dbo.CuteChat4_SupportFeedback ADD CONSTRAINT
	PK_CuteChat4_SupportFeedback PRIMARY KEY CLUSTERED 
	(
	FeedbackId
	) ON [PRIMARY]

GO
--
--
CREATE TABLE dbo.Tmp_CuteChat4_User
	(
	UserId nvarchar(50) NOT NULL,
	DisplayName nvarchar(100) NULL,
	Description nvarchar(300) NULL,
	BuildinIgnores ntext NULL,
	BuildinContacts ntext NULL,
	ServerProperties ntext NULL,
	PublicProperties ntext NULL,
	PrivateProperties ntext NULL
	)  ON [PRIMARY]
	 TEXTIMAGE_ON [PRIMARY]
GO
IF EXISTS(SELECT * FROM dbo.CuteChat4_User)
	 EXEC('INSERT INTO dbo.Tmp_CuteChat4_User (UserId, DisplayName, Description, BuildinIgnores, BuildinContacts, ServerProperties, PublicProperties, PrivateProperties)
		SELECT UserId, DisplayName, Description, BuildinIgnores, BuildinContacts, ServerProperties, PublicProperties, PrivateProperties FROM dbo.CuteChat4_User (HOLDLOCK TABLOCKX)')
GO
DROP TABLE dbo.CuteChat4_User
GO
EXECUTE sp_rename N'dbo.Tmp_CuteChat4_User', N'CuteChat4_User', 'OBJECT'
GO
ALTER TABLE dbo.CuteChat4_User ADD CONSTRAINT
	PK_CuteChat4_User PRIMARY KEY CLUSTERED 
	(
	UserId
	) ON [PRIMARY]

GO
--

IF @@ERROR<>0
BEGIN
	ROLLBACK TRANSACTION
	SELECT '-----------ERROR-----------' AS RESULT
END
ELSE
BEGIN
	COMMIT TRANSACTION
	SELECT '-----------DONE-----------' AS RESULT
END